@@ -9,6 +9,7 @@ from kcapi.ie import AuthenticationFlowsImporter
 from kcapi.ie.auth_flows import create_child_flow_data
 from kcapi.rest.auth_flows import AuthenticationExecutionsBaseCRUD
 from kcapi.rest.crud import KeycloakCRUD
+from kcfetcher.utils import normalize
 from sortedcontainers import SortedDict
 
 from kcloader.resource import SingleResource
@@ -62,7 +63,7 @@ class AuthenticationFlowManager(BaseManager):
 
     @classmethod
     def _object_filepaths(cls, datadir: str, realm: str):
-        return glob(os.path.join(datadir, f"{realm}/authentication/flows/*/*.json"))
+        return glob(os.path.join(datadir, f"{normalize(realm)}/authentication/flows/*/*.json"))
 
     def _object_docs(self):
         object_filepaths = self._object_filepaths(self.datadir, self.realm)
@@ -211,6 +212,10 @@ class AuthenticationFlowExecutionsManager(BaseManager):
         self._this_flow_executions_api = keycloak_api.build(f"authentication/flows/{flow_alias}/executions", realm)
         super().__init__(keycloak_api, realm, datadir)
 
+        flow_doc = read_from_json(flow_filepath)
+        self._builtin_flow = flow_doc["builtIn"]
+        self.flow_alias = flow_alias
+
         flow_executors_factory = FlowExecutorsFactory(flow_alias)
         resource = {
             'path': flow_filepath,
@@ -220,6 +225,15 @@ class AuthenticationFlowExecutionsManager(BaseManager):
         }
         self.resources = flow_executors_factory.create_child_executors(resource)
 
+    def publish(self, **publish_kwargs):
+        if self._builtin_flow:
+            # TODO if _builtin_flow, then execution.requirement value can be changed,
+            # but new executions/subflows cannot be added/removed.
+            # Hack - just ignore executions if _builtin_flow.
+            logger.warning(f"realm={self.realm} flow_alias={self.flow_alias} is built-in, executions will not be updated.")
+            return False
+        return super().publish(**publish_kwargs)
+
     def _object_docs_ids(self):
         return [resource.body["displayName"] for resource in self.resources]
 
@@ -233,6 +247,12 @@ class AuthenticationFlowExecutionsManager(BaseManager):
         # It is used also to .remove() objects on server.
         return self._auth_executions_api  # will work only for object remove, not for object list
 
+    def remove_server_object(self, delete_obj: dict):
+        if self._builtin_flow:
+            logger.error(f"Cannot remove execution from a builtin flow. Flow alias={self.flow_alias}, execution displayName={delete_obj['displayName']} id={delete_obj['id']}.")
+            return False
+        return super().remove_server_object(delete_obj)
+
 
 class AuthenticationExecutionsExecutionResource(SingleResource):
     _resource_name = "authentication/executions/{execution_id}"
