@@ -42,8 +42,8 @@ class Resource:
     def publish(self, body):
         return ResourcePublisher(self.key, body).publish(self._resource_api)
 
-    def publish_object(self, body, single_resource):
-        return ResourcePublisher(self.key, body, single_resource).publish(self._resource_api)
+    def publish_object(self, body, single_resource, params=None):
+        return ResourcePublisher(self.key, body, single_resource, params).publish(self._resource_api)
 
     def remove(self, body):
         id = self.get_resource_id(body)
